==> cfengine3_3.6.2.orig.tar.gz: cfengine-3.6.2/cf-agent/vercmp.h <==
/*
   Copyright (C) CFEngine AS

   This file is part of CFEngine 3 - written and maintained by CFEngine AS.

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; version 3.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

  To the extent this program is licensed as part of the Enterprise
  versions of CFEngine, the applicable Commercial Open Source License
  (COSL) may apply to this file if you as a licensee so wish it. See
  included file COSL.txt.
*/

#ifndef CFENGINE_VERCMP_H
#define CFENGINE_VERCMP_H

typedef enum
{
    VERCMP_ERROR = -1,
    VERCMP_NO_MATCH = 0,
    VERCMP_MATCH = 1
} VersionCmpResult;

/*
 * a, pp are used for
 *  a.packages.package_select
 *  a.packages.package_version_less_command
 *  a.packages.package_version_equal_command
 *  a.packages.package_commands_useshell
 *  cfPS
 */
VersionCmpResult CompareVersions(EvalContext *ctx, const char *v1, const char *v2, Attributes a, const Promise *pp, PromiseResult *result);

const char* PackageVersionComparatorToString(const PackageVersionComparator pvc);

#endif

==> cfengine3_3.10.2.orig.tar.gz: cfengine-3.10.2/cf-agent/vercmp.h <==
/*
   Copyright 2017 Northern.tech AS

   This file is part of CFEngine 3 - written and maintained by Northern.tech AS.

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; version 3.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA

  To the extent this program is licensed as part of the Enterprise
  versions of CFEngine, the applicable Commercial Open Source License
  (COSL) may apply to this file if you as a licensee so wish it. See
  included file COSL.txt.
*/

#ifndef CFENGINE_VERCMP_H
#define CFENGINE_VERCMP_H

typedef enum
{
    VERCMP_ERROR = -1,
    VERCMP_NO_MATCH = 0,
    VERCMP_MATCH = 1
} VersionCmpResult;

/*
 * a, pp are used for
 *  a.packages.package_select
 *  a.packages.package_version_less_command
 *  a.packages.package_version_equal_command
 *  a.packages.package_commands_useshell
 *  cfPS
 */
VersionCmpResult CompareVersions(EvalContext *ctx, const char *v1, const char *v2, Attributes a, const Promise *pp, PromiseResult *result);

const char* PackageVersionComparatorToString(const PackageVersionComparator pvc);

#endif
